@@ -39,7 +39,7 @@ getNewParams.SC <- function(theData, oldParams, beta.immig,  dr=0.001,r=4,
 
 
 E.step.SC.CTMC_PO_many <- function(theData, oldParams, beta.immig,  dr=0.001,
-                                   n.fft=1024, r=4, prec.tol, prec.fail.stop){
+                                   n.fft=1024, r=4, prec.tol=1e-12, prec.fail.stop=TRUE){
   n.Procs <- length(theData@BDMCsPO); ##badform to directly reference.
   ##resultMatrix <- sapply(theData@BDMCsPO,
   resultMatrix <- sapply(getBDMCsPOlist(theData), ## this has been modified and not tested
@@ -49,47 +49,81 @@ E.step.SC.CTMC_PO_many <- function(theData, oldParams, beta.immig,  dr=0.001,
   apply(resultMatrix, 1, sum);
 }
 
+
+## This seems to be as fast as the version with 4 calls to mapply, tested for N = 100
+## E.step.SC.CTMC_PO_1<- function(theData, oldParams, beta.immig,  dr=0.001,
+##                                n.fft=1024, r=4, prec.tol=1e-12, prec.fail.stop=TRUE){
+##   vec <- c(0,0,0);
+##   L <- oldParams[1];
+##   mu <- oldParams[2];
+##   nu <- beta.immig*L;
+##   N <- length(getStates(theData));
+##   for (i in 1:(N-1)){
+##     timeDiff <- getTimes(theData)[i+1] - getTimes(theData)[i];
+##     ##nfftSums <- max(n.fft, getStates(theData)[i+1]+1); #This is quite inefficient.  should code a 1-getter
+##     vec[1] <- vec[1]+
+##       add.cond.mean.one(lambda=L, mu=mu,
+##                         nu=nu, X0=getStates(theData)[i],
+##                         t=timeDiff, delta=dr,
+##                         Xt=getStates(theData)[i+1], n=n.fft,r=r,
+##                         prec.tol=prec.tol, prec.fail.stop=prec.fail.stop);
+##     vec[2] <- vec[2] +
+##       rem.cond.mean.one(lambda=L, mu=mu,
+##                         nu=nu, X0=getStates(theData)[i],
+##                         t=timeDiff, delta=dr,
+##                         Xt=getStates(theData)[i+1], n=n.fft,
+##                         r=r,prec.tol=prec.tol, prec.fail.stop=prec.fail.stop);
+##     vec[3] <- vec[3] +
+##       timeave.cond.mean.one(lambda=L, mu=mu,
+##                             nu=nu, X0=getStates(theData)[i],
+##                             t=timeDiff, delta=dr,
+##                             Xt=getStates(theData)[i+1], n=n.fft,r=r,
+##                             prec.tol=prec.tol, prec.fail.stop=prec.fail.stop);
+##   }
+##   names(  vec) <- c("Nplus","Nminus", "Holdtime");
+##   vec;
+## }
+
+
+## using mapply is not really faster than the for-loop in the old version,
+## commented out Have tested that this is identical to old version (with
+## for-loop) on a handful of different parameter values, but not
+## extraordinarily extensive.  (probably is an all-or-nothign situation
+## though)
 E.step.SC.CTMC_PO_1<- function(theData, oldParams, beta.immig,  dr=0.001,
-                               n.fft=1024, r=4, prec.tol, prec.fail.stop){
+                                      n.fft=1024, r=4, prec.tol=1e-12, prec.fail.stop=TRUE){
   vec <- c(0,0,0);
   L <- oldParams[1];
   mu <- oldParams[2];
   nu <- beta.immig*L;
   N <- length(getStates(theData));
-  for (i in 1:(N-1)){
-    timeDiff <- getTimes(theData)[i+1] - getTimes(theData)[i];
-    nfftSums <- max(n.fft, getStates(theData)[i+1]+1); #This is quite inefficient.  should code a 1-getter
-    vec[1] <- vec[1]+
-      add.cond.mean.one(lambda=L, mu=mu,
-                        nu=nu, X0=getStates(theData)[i],
-                        t=timeDiff, delta=dr,
-                        Xt=getStates(theData)[i+1], n=n.fft,r=r,
-                        prec.tol=prec.tol, prec.fail.stop=prec.fail.stop);
-    vec[2] <- vec[2] +
-      rem.cond.mean.one(lambda=L, mu=mu,
-                        nu=nu, X0=getStates(theData)[i],
-                        t=timeDiff, delta=dr,
-                        Xt=getStates(theData)[i+1], n=n.fft,
-                        r=r,prec.tol=prec.tol, prec.fail.stop=prec.fail.stop);
-    vec[3] <- vec[3] +
-      timeave.cond.mean.one(lambda=L, mu=mu,
-                            nu=nu, X0=getStates(theData)[i],
-                            t=timeDiff, delta=dr,
-                            Xt=getStates(theData)[i+1], n=n.fft,r=r,
-                            prec.tol=prec.tol, prec.fail.stop=prec.fail.stop);
-  }
+  arglist <- list(lambda=L,mu=mu,nu=nu,delta=dr,n=n.fft,r=r,prec.tol=prec.tol,
+                  prec.fail.stop=prec.fail.stop)
+  timeDiff <- diff(getTimes(theData))
+  trans.probs <- mapply(process.prob.one, t=timeDiff,
+                        X0=getStates(theData)[1:(N-1)], Xt=getStates(theData)[2:N],
+                        MoreArgs=list(lambda=L,mu=mu,nu=nu,n=n.fft),
+                        SIMPLIFY=TRUE)
+  vec[1] <- sum(mapply(add.cond.mean.one, t=timeDiff,X0=getStates(theData)[1:(N-1)], Xt=getStates(theData)[2:N],
+                       trans.prob=trans.probs,
+                       MoreArgs=arglist, SIMPLIFY=TRUE))
+  vec[2] <- sum(mapply(rem.cond.mean.one, t=timeDiff,X0=getStates(theData)[1:(N-1)], Xt=getStates(theData)[2:N],
+                       MoreArgs=arglist, SIMPLIFY=TRUE))
+  vec[3] <- sum(mapply(timeave.cond.mean.one, t=timeDiff,X0=getStates(theData)[1:(N-1)], Xt=getStates(theData)[2:N],
+                       MoreArgs=arglist, SIMPLIFY=TRUE
+                       ))
   names(  vec) <- c("Nplus","Nminus", "Holdtime");
   vec;
 }
 
 
 E.step.SC.list <- function(theData, oldParams, beta.immig,  dr=0.001,
-                           n.fft=1024,r=4, prec.tol, prec.fail.stop){
+                           n.fft=1024,r=4, prec.tol=1e-12, prec.fail.stop=TRUE){
   vec <- c(0,0,0);
   L <- oldParams[1];
   mu <- oldParams[2];
   nu <- beta.immig*L;
-  N <- length(theData$states);
+  N <- length(getTimes(theData));
   for (i in 1:(N-1)){
     timeDiff <- theData$times[i+1] - theData$times[i];
     nfftSums <- max(n.fft, theData$states[i+1]+1); #This is quite inefficient.  should code a 1-getter
